@@ -1,13 +1,13 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize.pm 100948 2009-02-20T04:07:52.965534Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize.pm 103047 2009-04-01T01:39:18.931794Z daisuke  $
 
 package Data::Localize;
-use Moose;
-use Moose::Util::TypeConstraints;
-use MooseX::AttributeHelpers;
+use Any::Moose;
+use Any::Moose '::Util::TypeConstraints';
+use Any::Moose 'X::AttributeHelpers';
 use I18N::LangTags ();
 use I18N::LangTags::Detect ();
 
-our $VERSION = '0.00001';
+our $VERSION = '0.00006_01';
 our $AUTHORITY = 'cpan:DMAKI';
 
 BEGIN {
@@ -74,7 +74,7 @@ coerce 'Data::Localize::LocalizerListArg'
             if ($klass !~ s/^\+//) {
                 $klass = "Data::Localize::$klass";
             }
-            Class::MOP::load_class($klass);
+            Any::Moose::load_class($klass);
             $klass->new(%$args);
         } @$_ ];
         return $ret;
@@ -88,8 +88,9 @@ has 'localizers' => (
     coerce => 1,
     default => sub { +[] },
     provides => {
-        push => 'push_localizers',
-        count => 'count_localizers',
+        'push'  => 'push_localizers',
+        'count' => 'count_localizers',
+        'grep'  => 'grep_localizers',
     }
 );
 
@@ -106,8 +107,8 @@ has 'localizer_map' => (
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose;
-no Moose::Util::TypeConstraints;
+no Any::Moose;
+no Any::Moose '::Util::TypeConstraints';
 
 sub BUILD {
     my $self = shift;
@@ -188,7 +189,7 @@ sub localize {
             }
             my $out = $localizer->localize_for(
                 lang => $lang,
-                id => $key,
+                id   => $key,
                 args => \@args
             );
             if ($out) {
@@ -204,6 +205,9 @@ sub localize {
     # if you got here, and you /still/ can't find a proper localization,
     # then we fallback to 'auto' feature
     if ($self->auto) {
+        if (DEBUG) {
+            print STDERR "[Data::Localize]: localize - trying auto-lexicon for $key\n";
+        }
         return $self->auto_localizer->localize_for(id => $key, args => \@args);
     }
 
@@ -222,7 +226,7 @@ sub add_localizer {
         if ($klass !~ s/^\+//) {
             $klass = "Data::Localize::$klass";
         }
-        Class::MOP::load_class($klass);
+        Any::Moose::load_class($klass);
 
         $localizer = $klass->new(%args);
     }
@@ -231,6 +235,14 @@ sub add_localizer {
     $self->push_localizers($localizer);
 }
 
+sub find_localizers {
+    my ($self, %args) = @_;
+
+    if (my $isa = $args{isa}) {
+        return $self->grep_localizers(sub { $_[0]->isa($isa) });
+    }
+}
+
 sub add_localizer_map {
     my ($self, $lang, $localizer) = @_;
 
@@ -255,9 +267,9 @@ Data::Localize - Alternate Data Localization API
 
 =head1 SYNOPSIS
 
-    use Data::Localizer;
+    use Data::Localize;
 
-    my $loc = Data::Localizer->new();
+    my $loc = Data::Localize->new();
     $loc->add_localizer(
         class     => "Namespace", # Locale::Maketext-style .pm files
         namespace => "MyApp::I18N"
@@ -311,7 +323,7 @@ which allows you to pass a non-existing key to the localize() method, and
 use it as the actual lexicon, if no other applicable lexicons exists.
 
     # here, we're deliberately not setting any localizers
-    my $loc = Data::Localizer->new(auto => 1);
+    my $loc = Data::Localize->new(auto => 1);
 
     print $loc->localize('Hello, [_1]', 'John Doe'), "\n";
 
@@ -324,6 +336,26 @@ don't have to place _AUTO everwhere.
 All data is expected to be in decoded utf8. You must "use utf8" for all values
 passed to Data::Localizer. We won't try to be smart for you. USE UTF8!
 
+=head1 USING ALTERNATE STORAGE
+
+By default all lexicons are stored on memory, but if you're building an app
+with thousands and thousands of long messages, this might not be the ideal
+solution. In such cases, you can change where the lexicons get stored
+
+    my $loc = Data::Localize->new();
+    $loc->add_namespace(
+        class         => 'Gettext',
+        path          => '/path/to/data/*.po'
+        storage_class => 'BerkeleyDB',
+        storage_args  => {
+            dir => '/path/to/really/fast/device'
+        }
+    );
+
+This would cause Data::Localize to put all the lexicon data in several BerkeleyDB files under /path/to/really/fast/device
+
+Note that this approach would buy you no gain if you use Data::Localize::Namespace, as that approach by default expects everything to be in memory.
+
 =head1 DEBUGGING
 
 =head2 DEBUG
@@ -365,10 +397,20 @@ Detects the current set of languages to use. If used in an CGI environment,
 will attempt to detect the language of choice from headers. See
 I18N::LanguageTags::Detect for details.
 
+=head2 detect_languages_from_header 
+
+Detects the language from the given header value, or from HTTP_ACCEPT_LANGUAGES environment variable
+
 =head2 add_localizer_map
 
 Used internally.
 
+=head2 find_localizers 
+
+Finds a localizer by its attribute. Currently only supports isa
+
+    my @locs = $loc->find_localizers(isa => 'Data::Localize::Gettext');
+
 =head2 set_languages
 
 If used without any arguments, calls detect_languages() and sets the
