@@ -1,16 +1,18 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Auto.pm 100948 2009-02-20T04:07:52.965534Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Auto.pm 103047 2009-04-01T01:39:18.931794Z daisuke  $
 
 package Data::Localize::Auto;
-use Moose;
+use Any::Moose;
 
 with 'Data::Localize::Localizer';
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose;
+no Any::Moose;
 
 sub register {}
 
+sub lexicon_get {}
+
 sub localize_for {
     my ($self, %args) = @_;
     my ($id, $args) = @args{ qw(id args) };
@@ -38,6 +40,8 @@ Data::Localize::Auto - Fallback Localizer
 
 =head2 register
 
+=head2 lexicon_get
+
 Does nothing
 
 =head2 localize_for
