@@ -1,8 +1,8 @@
-# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Namespace.pm 100948 2009-02-20T04:07:52.965534Z daisuke  $
+# $Id: /mirror/coderepos/lang/perl/Data-Localize/trunk/lib/Data/Localize/Namespace.pm 103044 2009-04-01T01:17:04.738082Z daisuke  $
 
 package Data::Localize::Namespace;
-use Moose;
-use MooseX::AttributeHelpers;
+use Any::Moose;
+use Any::Moose 'X::AttributeHelpers';
 use Module::Pluggable::Object;
 use Encode ();
 
@@ -20,7 +20,7 @@ has 'namespaces' => (
 
 __PACKAGE__->meta->make_immutable;
 
-no Moose;
+no Any::Moose;
 
 sub register {
     my ($self, $loc) = @_;
@@ -41,7 +41,7 @@ sub register {
 
 our %LOADED;
 sub lexicon_get {
-    my ($self, $lang) = @_;
+    my ($self, $lang, $id) = @_;
 
     foreach my $namespace ($self->namespaces) {
         my $klass = "$namespace\::$lang";
@@ -62,7 +62,9 @@ sub lexicon_get {
                 if (&Data::Localize::DEBUG) {
                     print STDERR "[Data::Localize::Namespace]: lexicon_get - loading $klass\n";
                 }
-                eval "require $klass";
+
+                my $code = "\n#line " . __LINE__ . ' "' . __FILE__ . "\"\nrequire $klass";
+                eval $code;
                 if ($@) {
                     if (&Data::Localize::DEBUG) {
                         print STDERR "[Data::Localize::Namespace]: lexicon_get - Failed to load $klass: $@\n";
@@ -78,9 +80,7 @@ sub lexicon_get {
         }
 
         if (&Data::Localize::DEBUG) {
-            print STDERR "[Data::Localize::Namespace]: returning lexicon from $klass\n";
-            require Data::Dumper;
-            print STDERR Data::Dumper::Dumper(\%{"$klass\::Lexicon"});
+            print STDERR "[Data::Localize::Namespace]: returning lexicon from $klass (", scalar keys %{"$klass\::Lexicon"}, " lexicons)\n";
         }
         my $h = \%{ "$klass\::Lexicon" };
         if ($first_load) {
@@ -97,7 +97,7 @@ sub lexicon_get {
             %$h = ();
             %$h = %t;
         }
-        return $h;
+        return $h->{$id};
         
     }
     return ();
